package de.doggoat.growableRebalance.listeners;

import de.doggoat.growableRebalance.PlantUtils;
import org.bukkit.Location;
import org.bukkit.Material;
import org.bukkit.event.EventHandler;
import org.bukkit.event.Listener;
import org.bukkit.event.block.BlockGrowEvent;
import org.bukkit.plugin.java.JavaPlugin;
import java.util.logging.Logger;
import java.util.Arrays;
import java.util.List;

public class BlockGrowEventListener implements Listener {

    List<Material> forbiddenGrowthBlocks = Arrays.asList(
            Material.MOSS_BLOCK, Material.MUD,
            Material.MUDDY_MANGROVE_ROOTS, Material.SUSPICIOUS_GRAVEL,
            Material.SUSPICIOUS_SAND
    );
    List<Material> allowedGourdGrowthBlocks = Arrays.asList(Material.GRASS_BLOCK, Material.DIRT, Material.FARMLAND);
    JavaPlugin plugin;
    Logger log;

    public BlockGrowEventListener(JavaPlugin plugin) {
        this.plugin = plugin;
        this.log = plugin.getLogger();
    }

    @EventHandler
    public void onBlockGrow(BlockGrowEvent e) {
        switch (e.getNewState().getType()) {
            case SWEET_BERRY_BUSH:
                this.onGroundBelow(e);
                break;
            case SUGAR_CANE:
            case CACTUS:
                this.onStackableGrow(e);
                break;
            case MELON:
            case PUMPKIN:
                this.onGourdGrow(e);
                break;
        }

    }

    public void onGourdGrow(BlockGrowEvent e) {
        Location ground = PlantUtils.getSingleBlockGround(e.getBlock().getLocation());
        if (!allowedGourdGrowthBlocks.contains(ground.getBlock().getType())) {
            e.setCancelled(true);
        }
    }

    public void onGroundBelow(BlockGrowEvent e) {
        Location ground = PlantUtils.getVerticalPlantGround(e.getBlock().getLocation());
        if (forbiddenGrowthBlocks.contains(ground.getBlock().getType())) {
            e.setCancelled(true);
        }
    }

    public void onStackableGrow(BlockGrowEvent e) {
        Location plantStart = e.getBlock().getLocation().add(0, -1, 0);
        Location ground = PlantUtils.getVerticalPlantGround(plantStart);
        if (forbiddenGrowthBlocks.contains(ground.getBlock().getType())) {
            e.setCancelled(true);
        }
    }

}
